@@ -94,9 +94,7 @@ describe <- function(data, dvar, pvar, mvar) {
     N = N
   )
   class(out) <- c("sc_desc")
-  attr(out, opt("phase")) <- pvar
-  attr(out, opt("mt")) <- mvar
-  attr(out, opt("dv")) <- dvar
+  attributes(out)[opts("phase", "mt", "dv")] <- list(pvar, mvar, dvar)
 
   out
 }
