@@ -4,15 +4,10 @@ export.sc_pnd <- function(object,
                           caption = NA, 
                           footnote = NA, 
                           filename = NA,
-                          kable_styling_options = list(), 
-                          kable_options = list(), 
                           select = c("Case", "PND", "Total", "Exceeds"),
                           round = 2,
                           ...) {
   
-  kable_options <- .join_kabel(kable_options)
-  kable_styling_options <- .join_kabel_styling(kable_styling_options)
-  
   if (is.na(caption)) caption <- c("Percentage Non-Overlapping Data")
   
   out <- data.frame(
@@ -27,8 +22,6 @@ export.sc_pnd <- function(object,
   
   table <- .create_table(
     out, 
-    kable_options, 
-    kable_styling_options, 
     caption = caption,
     footnote = footnote,
     ...
