@@ -12,7 +12,7 @@ add_message <- function(..., collapse = "") {
   messages$messages <- c(messages$messages, msg)
 }
 
-print_messages <- function(warning = FALSE) {
+print_messages <- function(warning = FALSE, pretext = NULL) {
   msg <- messages$messages
   if (length(msg) == 0) return(FALSE)
   msg <- table(msg)
@@ -22,7 +22,7 @@ print_messages <- function(warning = FALSE) {
   msg <- paste0(1:length(msg), ": ", names(msg), collapse = "\n")
   msg <- paste0("\n", msg, "\n")
   
-  if (warning) warning(msg, call. = FALSE) else message(msg)
+  if (warning) warning(msg, call. = FALSE) else message(pretext, msg)
   
   reset_messages()
 }
