@@ -119,8 +119,6 @@ mplm <- function(data, dvar, mvar, pvar,
     class = c("sc_mplm")
   )
 
-  attr(out, opt("phase")) <- pvar
-  attr(out, opt("mt")) <- mvar
-  attr(out, opt("dv")) <- dvar
+  attributes(out)[opts("phase", "mt", "dv")] <- list(pvar, mvar, dvar)
   out
 }
