@@ -182,8 +182,6 @@ outlier <- function(data, dvar, pvar, mvar,
   out$case.names <- case.names
   
   class(out) <- c("sc_outlier")
-  attr(out, opt("phase")) <- pvar
-  attr(out, opt("mt")) <- mvar
-  attr(out, opt("dv")) <- dvar
+  attributes(out)[opts("phase", "mt", "dv")] <- list(pvar, mvar, dvar)
   out
 }
