@@ -211,8 +211,7 @@ pand <- function(data, dvar, pvar,
   }
 
   class(out) <- c("sc_pand")
-  attr(out, opt("phase")) <- pvar
-  attr(out, opt("dv")) <- dvar
+  attributes(out)[opts("phase", "dv")] <- list(pvar, dvar)
   out
 }
 
