@@ -131,8 +131,7 @@ rci <- function(data, dvar, pvar,
     rdd = rdd
   ) 
   class(out) <- c("sc_rci")
-  attr(out, opt("phase")) <- pvar
-  attr(out, opt("dv")) <- dvar
+  attributes(out)[opts("phase", "dv")] <- list(pvar, dvar)
   out
 }
 
